==> cloudwatch-1.191.0-sources.jar: software/amazon/awscdk/services/cloudwatch/IMetric.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Interface for metrics.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.73.0 (build 6faeda3)", date = "2023-01-31T18:36:51.277Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.IMetric")
@software.amazon.jsii.Jsii.Proxy(IMetric.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IMetric extends software.amazon.jsii.JsiiSerializable {

    /**
     * Any warnings related to this metric.
     * <p>
     * Should be attached to the consuming construct.
     * <p>
     * Default: - None
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWarnings() {
        return null;
    }

    /**
     * (deprecated) Turn this metric object into an alarm configuration.
     * <p>
     * @deprecated Use `toMetricConfig()` instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig toAlarmConfig();

    /**
     * (deprecated) Turn this metric object into a graph configuration.
     * <p>
     * @deprecated Use `toMetricConfig()` instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricGraphConfig toGraphConfig();

    /**
     * Inspect the details of the metric object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricConfig toMetricConfig();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cloudwatch.IMetric.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Any warnings related to this metric.
         * <p>
         * Should be attached to the consuming construct.
         * <p>
         * Default: - None
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWarnings() {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "warnings", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
        }

        /**
         * (deprecated) Turn this metric object into an alarm configuration.
         * <p>
         * @deprecated Use `toMetricConfig()` instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig toAlarmConfig() {
            return software.amazon.jsii.Kernel.call(this, "toAlarmConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig.class));
        }

        /**
         * (deprecated) Turn this metric object into a graph configuration.
         * <p>
         * @deprecated Use `toMetricConfig()` instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricGraphConfig toGraphConfig() {
            return software.amazon.jsii.Kernel.call(this, "toGraphConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricGraphConfig.class));
        }

        /**
         * Inspect the details of the metric object.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricConfig toMetricConfig() {
            return software.amazon.jsii.Kernel.call(this, "toMetricConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricConfig.class));
        }
    }

    /**
     * Internal default implementation for {@link IMetric}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IMetric {

        /**
         * Any warnings related to this metric.
         * <p>
         * Should be attached to the consuming construct.
         * <p>
         * Default: - None
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWarnings() {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "warnings", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
        }

        /**
         * (deprecated) Turn this metric object into an alarm configuration.
         * <p>
         * @deprecated Use `toMetricConfig()` instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig toAlarmConfig() {
            return software.amazon.jsii.Kernel.call(this, "toAlarmConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig.class));
        }

        /**
         * (deprecated) Turn this metric object into a graph configuration.
         * <p>
         * @deprecated Use `toMetricConfig()` instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricGraphConfig toGraphConfig() {
            return software.amazon.jsii.Kernel.call(this, "toGraphConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricGraphConfig.class));
        }

        /**
         * Inspect the details of the metric object.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricConfig toMetricConfig() {
            return software.amazon.jsii.Kernel.call(this, "toMetricConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricConfig.class));
        }
    }
}

==> cloudwatch-1.204.0-sources.jar: software/amazon/awscdk/services/cloudwatch/IMetric.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Interface for metrics.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:36.866Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.IMetric")
@software.amazon.jsii.Jsii.Proxy(IMetric.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IMetric extends software.amazon.jsii.JsiiSerializable {

    /**
     * Any warnings related to this metric.
     * <p>
     * Should be attached to the consuming construct.
     * <p>
     * Default: - None
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWarnings() {
        return null;
    }

    /**
     * (deprecated) Turn this metric object into an alarm configuration.
     * <p>
     * @deprecated Use <code>toMetricConfig()</code> instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig toAlarmConfig();

    /**
     * (deprecated) Turn this metric object into a graph configuration.
     * <p>
     * @deprecated Use <code>toMetricConfig()</code> instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricGraphConfig toGraphConfig();

    /**
     * Inspect the details of the metric object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricConfig toMetricConfig();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cloudwatch.IMetric.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Any warnings related to this metric.
         * <p>
         * Should be attached to the consuming construct.
         * <p>
         * Default: - None
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWarnings() {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "warnings", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
        }

        /**
         * (deprecated) Turn this metric object into an alarm configuration.
         * <p>
         * @deprecated Use <code>toMetricConfig()</code> instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig toAlarmConfig() {
            return software.amazon.jsii.Kernel.call(this, "toAlarmConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig.class));
        }

        /**
         * (deprecated) Turn this metric object into a graph configuration.
         * <p>
         * @deprecated Use <code>toMetricConfig()</code> instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricGraphConfig toGraphConfig() {
            return software.amazon.jsii.Kernel.call(this, "toGraphConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricGraphConfig.class));
        }

        /**
         * Inspect the details of the metric object.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricConfig toMetricConfig() {
            return software.amazon.jsii.Kernel.call(this, "toMetricConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricConfig.class));
        }
    }

    /**
     * Internal default implementation for {@link IMetric}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IMetric {

        /**
         * Any warnings related to this metric.
         * <p>
         * Should be attached to the consuming construct.
         * <p>
         * Default: - None
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWarnings() {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "warnings", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
        }

        /**
         * (deprecated) Turn this metric object into an alarm configuration.
         * <p>
         * @deprecated Use <code>toMetricConfig()</code> instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig toAlarmConfig() {
            return software.amazon.jsii.Kernel.call(this, "toAlarmConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricAlarmConfig.class));
        }

        /**
         * (deprecated) Turn this metric object into a graph configuration.
         * <p>
         * @deprecated Use <code>toMetricConfig()</code> instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricGraphConfig toGraphConfig() {
            return software.amazon.jsii.Kernel.call(this, "toGraphConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricGraphConfig.class));
        }

        /**
         * Inspect the details of the metric object.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.MetricConfig toMetricConfig() {
            return software.amazon.jsii.Kernel.call(this, "toMetricConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.MetricConfig.class));
        }
    }
}
